@@ -12,29 +12,25 @@ def user_has_subscriptions_in_products_list(user, products):
     :param products: a set of product ids which the user must be subscribed to
     '''
 
+    # get the customer using the user's email
+    # TODO: https://git.startinblox.com/djangoldp-packages/djangoldp-stripe/-/issues/1
+    user_customer = Customer.objects.filter(email=user.email)
+    if not user_customer.exists():
+        return False
+    
+    user_customer = user_customer[0]
+    
     # fetch the products which the user is subscribed to
-    try:
-        # get the customer using the user's email
-        # TODO: https://git.startinblox.com/djangoldp-packages/djangoldp-stripe/-/issues/1
-        user_customer = Customer.objects.filter(email=user.email)
-        if user_customer.exists():
-            user_customer = user_customer[0]
-        
-        user_subscriptions = [s.id for s in user_customer._get_valid_subscriptions()]
-        user_subscriptions = SubscriptionItem.objects.filter(subscription__in=user_subscriptions)
-        user_plan_ids = [i.plan for i in user_subscriptions]
-        user_products = set(Plan.objects.filter(id__in=user_plan_ids).values_list('product', flat=True))
-    
-        # reject if there are any required products missing from the user
-        if len(products.difference(user_products)) > 0:
-            return False
-        
-        return True
+    user_subscriptions = [s.id for s in user_customer._get_valid_subscriptions()]
+    user_subscriptions = SubscriptionItem.objects.filter(subscription__in=user_subscriptions)
+    user_plan_ids = [i.plan for i in user_subscriptions]
+    user_products = set(Plan.objects.filter(id__in=user_plan_ids).values_list('product', flat=True))
 
-    except Customer.DoesNotExist:
-        pass
+    # reject if there are any required products missing from the user
+    if len(products.difference(user_products)) > 0:
+        return False
     
-    return False
+    return True
 
 
 def user_has_subscriptions_for_model(user, model):
